# disjoint_set
[DisjointSet data](https://en.wikipedia.org/wiki/Disjoint-set_data_structure) structure implementation for Python

![PyPI - License](https://img.shields.io/pypi/l/disjoint_set.svg)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/disjoint_set.svg)
![PyPI](https://img.shields.io/pypi/v/disjoint_set.svg)

## Prerequisites

The only requirement is having Python 3 installed, you can verify this by running:
```bash
$ python --version
Python 3.7.2
```

## Installation

```
pip install disjoint_set
```

You can verify he package was installed to your current environment by running:
```bash
pip list | grep -F package_name
```

## Usage




## Contributing

Feel free to leave any issues

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/your/project/tags). 

## Authors

* [Maciej Rapacz](https://github.com/mrapacz/)


## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details
